/*
 * Copyright 2010 Boris Kochergin. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER ``AS IS'' AND ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef VDEV_HPP
#define VDEV_HPP

#include <string>
#include <map>
#include <utility>

class VDev {
  public:
    VDev(const std::string _name, const vdev_state_t _status,
         const std::string _statusName);
    const std::string &name() const;
    const vdev_state_t &status() const;
    const std::string &statusName() const;
    void add(const std::string dev, const vdev_state_t _status,
             const std::string _statusName);
    const std::map <std::string, std::pair <vdev_state_t,
                                            std::string> > &devs() const;
  private:
    std::string __name;
    vdev_state_t __status;
    std::string __statusName;
    std::map <std::string, std::pair <vdev_state_t, std::string> > _devs;
};

VDev::VDev(const std::string _name, const vdev_state_t _status,
           const std::string _statusName) {
  __name = _name;
  __status = _status;
  __statusName = _statusName;
}

const std::string &VDev::name() const {
  return __name;
}

const vdev_state_t &VDev::status() const {
  return __status;
}

const std::string &VDev::statusName() const {
  return __statusName;
}

void VDev::add(const std::string dev, const vdev_state_t _status,
               const std::string _statusName) {
  _devs.insert(std::make_pair(dev, std::make_pair(_status, _statusName)));
}

const std::map <std::string, std::pair <vdev_state_t, 
                                        std::string> > &VDev::devs() const {
  return _devs;
}

#endif
